@@ -2,7 +2,9 @@
 /*
 Plugin Name: CiviCRM
 Description: CiviCRM - Growing and Sustaining Relationships
-Version: 5.25.0
+Version: 5.28.4
+Requires at least: 4.9
+Requires PHP:      7.1
 Author: CiviCRM LLC
 Author URI: https://civicrm.org/
 Plugin URI: https://docs.civicrm.org/sysadmin/en/latest/install/wordpress/
@@ -54,7 +56,7 @@ if ( ! defined( 'ABSPATH' ) ) exit;
 
 
 // Set version here: when it changes, will force JS to reload
-define( 'CIVICRM_PLUGIN_VERSION', '5.25.0' );
+define( 'CIVICRM_PLUGIN_VERSION', '5.28.4' );
 
 // Store reference to this file
 if (!defined('CIVICRM_PLUGIN_FILE')) {
@@ -204,6 +206,15 @@ class CiviCRM_For_WordPress {
    */
   public $users;
 
+  /**
+   * Compatibility object.
+   *
+   * @since 5.24
+   * @access public
+   * @var object CiviCRM_For_WordPress_Compat The plugin compatibility object.
+   */
+  public $compat;
+
 
   // ---------------------------------------------------------------------------
   // Setup
@@ -349,16 +360,8 @@ class CiviCRM_For_WordPress {
       wp_die( __( 'Only one instance of CiviCRM_For_WordPress please', 'civicrm' ) );
     }
 
-    // Get existing session ID
-    $session_id = session_id();
-
-    /*
-     * There is no session handling in WP - hence we start it for CiviCRM pages
-     * except when running via WP-CLI which does not require sessions.
-     */
-    if ( empty( $session_id ) && ! ( defined( 'WP_CLI' ) && WP_CLI ) ) {
-      session_start();
-    }
+    // Maybe start session.
+    $this->maybe_start_session();
 
     /*
      * AJAX calls do not set the 'cms.root' item, so make sure it is set here so
@@ -394,6 +397,53 @@ class CiviCRM_For_WordPress {
   }
 
 
+  /**
+   * Maybe start a session for CiviCRM.
+   *
+   * There is no session handling in WordPress so start it for CiviCRM pages.
+   *
+   * Not needed when running:
+   *
+   * - via WP-CLI
+   * - via wp-cron.php
+   * - via PHP on the command line
+   *
+   * none of which require sessions.
+   *
+   *
+   * @since 5.28
+   */
+  public function maybe_start_session() {
+
+    // Get existing session ID
+    $session_id = session_id();
+
+    // Check WordPress pseudo-cron.
+    $wp_cron = FALSE;
+    if (function_exists('wp_doing_cron') && wp_doing_cron()) {
+      $wp_cron = TRUE;
+    }
+
+    // Check WP-CLI.
+    $wp_cli = FALSE;
+    if (defined('WP_CLI') && WP_CLI) {
+      $wp_cli = TRUE;
+    }
+
+    // Check PHP on the command line - e.g. `cv`.
+    $php_cli = TRUE;
+    if (PHP_SAPI !== 'cli') {
+      $php_cli = FALSE;
+    }
+
+    // Maybe start session.
+    if (empty($session_id) && !$wp_cron && !$wp_cli && !$php_cli) {
+      session_start();
+    }
+
+  }
+
+
   /**
    * Set broad CiviCRM context.
    *
@@ -410,8 +460,8 @@ class CiviCRM_For_WordPress {
    */
   public function civicrm_in_wordpress_set() {
 
-    // Get identifying query var
-    $page = get_query_var( 'page' );
+    // Get identifying query var.
+    $page = get_query_var( 'civiwp' );
 
     // Store
     self::$in_wordpress = ( $page == 'CiviCRM' ) ? TRUE : FALSE;
@@ -527,6 +577,10 @@ class CiviCRM_For_WordPress {
     include_once CIVICRM_PLUGIN_DIR . 'includes/civicrm.basepage.php';
     $this->basepage = new CiviCRM_For_WordPress_Basepage;
 
+    // Include compatibility class
+    include_once CIVICRM_PLUGIN_DIR . 'includes/civicrm.compat.php';
+    $this->compat = new CiviCRM_For_WordPress_Compat;
+
     if ( ! class_exists( 'CiviCRM_WP_REST\Autoloader' ) ) {
       // Include REST API autoloader class
       require_once( CIVICRM_PLUGIN_DIR . 'wp-rest/Autoloader.php' );
@@ -565,6 +619,12 @@ class CiviCRM_For_WordPress {
     // Go no further if CiviCRM not installed yet
     if ( ! CIVICRM_INSTALLED ) return;
 
+    // Attempt to replace 'page' query arg with 'civiwp'.
+    add_filter( 'request', array( $this, 'maybe_replace_page_query_var' ) );
+
+    // Add our query vars.
+    add_filter( 'query_vars', array( $this, 'query_vars' ) );
+
     // Delay everything else until query has been parsed
     add_action( 'parse_query', array( $this, 'register_hooks_front_end' ) );
 
@@ -597,6 +657,14 @@ class CiviCRM_For_WordPress {
     }
     $alreadyRegistered = TRUE;
 
+    // Redirect if old query var is present.
+    if ( 'CiviCRM' == get_query_var( 'page' ) && 'CiviCRM' != get_query_var( 'civiwp' ) ) {
+      $redirect_url = remove_query_arg( 'page', false );
+      $redirect_url = add_query_arg( 'civiwp', 'CiviCRM', $redirect_url );
+      wp_redirect( $redirect_url, 301 );
+      exit();
+    }
+
     // Store context
     $this->civicrm_in_wordpress_set();
 
@@ -707,9 +775,6 @@ class CiviCRM_For_WordPress {
 
     }
 
-    // Add our query vars.
-    add_filter( 'query_vars', array( $this, 'query_vars' ) );
-
   }
 
 
@@ -746,9 +811,34 @@ class CiviCRM_For_WordPress {
     // Enable shortcode modal
     $this->modal->register_hooks();
 
+		// Prevent auto-updates.
+		add_filter( 'plugin_auto_update_setting_html', [ $this, 'auto_update_prevent' ], 10, 3 );
+
   }
 
 
+	/**
+	 * Prevent auto-updates of this plugin in WordPress 5.5.
+	 *
+	 * @link https://make.wordpress.org/core/2020/07/15/controlling-plugin-and-theme-auto-updates-ui-in-wordpress-5-5/
+	 *
+	 * @since 5.28
+	 */
+	function auto_update_prevent( $html, $plugin_file, $plugin_data ) {
+
+		// Test for this plugin.
+		$this_plugin = plugin_basename( dirname( __FILE__ ) . '/civicrm.php' );
+		if ( $this_plugin === $plugin_file ) {
+			$html = __( 'Auto-updates are not available for this plugin.', 'civicrm' );
+		}
+
+		// --<
+		return $html;
+
+	}
+
+
+
   /**
    * Force rewrite rules to be recreated.
    *
@@ -800,7 +890,7 @@ class CiviCRM_For_WordPress {
     // Let's add rewrite rule when viewing the basepage
     add_rewrite_rule(
       '^' . $config->wpBasePage . '/([^?]*)?',
-      'index.php?page_id=' . $basepage->ID . '&page=CiviCRM&q=civicrm%2F$matches[1]',
+      'index.php?page_id=' . $basepage->ID . '&civiwp=CiviCRM&q=civicrm%2F$matches[1]',
       'top'
     );
 
@@ -813,10 +903,12 @@ class CiviCRM_For_WordPress {
      * Broadcast the rewrite rules event.
      *
      * @since 5.7
+     * @since 5.24 Added $basepage parameter.
      *
      * @param bool $flush_rewrite_rules True if rules flushed, false otherwise.
+     * @param WP_Post $basepage The Basepage post object.
      */
-    do_action( 'civicrm_after_rewrite_rules', $flush_rewrite_rules );
+    do_action( 'civicrm_after_rewrite_rules', $flush_rewrite_rules, $basepage );
 
   }
 
@@ -838,7 +930,7 @@ class CiviCRM_For_WordPress {
 
     // Build our query vars
     $civicrm_query_vars = array(
-      'page', 'q', 'reset', 'id', 'html', 'snippet', // URL query vars
+      'civiwp', 'q', 'reset', 'id', 'html', 'snippet', // URL query vars
       'action', 'mode', 'cid', 'gid', 'sid', 'cs', 'force', // Shortcode query vars
     );
 
@@ -866,6 +958,36 @@ class CiviCRM_For_WordPress {
   }
 
 
+  /**
+   * Filters the request right after WP's
+   * parsed it and replaces the 'page' query
+   * variable with 'civiwp' if applicable.
+   *
+   * Prevents old URLs like example.org/civicrm/?page=CiviCRM&q=what/ever/path&reset=1
+   * being redirected to example.org/civicrm/?civiwp=CiviCRM&q=what/ever/path&reset=1
+   *
+   * @see https://lab.civicrm.org/dev/wordpress/-/issues/49
+   *
+   * @since 5.26
+   *
+   * @param array $query_vars The existing query vars.
+   * @return array $query_vars The modified query vars.
+   */
+  public function maybe_replace_page_query_var( $query_vars ) {
+
+    $civi_query_arg = array_search( 'CiviCRM', $query_vars );
+
+    // Bail if the query var is not 'page'.
+    if ( false === $civi_query_arg || $civi_query_arg !== 'page' ) return $query_vars;
+
+    unset( $query_vars['page'] );
+    $query_vars['civiwp'] = 'CiviCRM';
+
+    return $query_vars;
+
+  }
+
+
   // ---------------------------------------------------------------------------
   // CiviCRM Initialisation
   // ---------------------------------------------------------------------------
@@ -1522,7 +1644,7 @@ class CiviCRM_For_WordPress {
     $q = get_query_var( 'q' );
     if (!empty($q)) {
 
-      $page = get_query_var( 'page' );
+      $page = get_query_var( 'civiwp' );
       $reset = get_query_var( 'reset' );
       $id = get_query_var( 'id' );
       $html = get_query_var( 'html' );
@@ -1537,7 +1659,7 @@ class CiviCRM_For_WordPress {
       $force = get_query_var( 'force' );
 
       $_REQUEST['q'] = $_GET['q'] = $q;
-      $_REQUEST['page'] = $_GET['page'] = 'CiviCRM';
+      $_REQUEST['civiwp'] = $_GET['civiwp'] = 'CiviCRM';
       if (!empty($reset)) { $_REQUEST['reset'] = $_GET['reset'] = $reset; }
       if (!empty($id)) { $_REQUEST['id'] = $_GET['id'] = $id; }
       if (!empty($html)) { $_REQUEST['html'] = $_GET['html'] = $html; }
@@ -1663,6 +1785,8 @@ class CiviCRM_For_WordPress {
 
     if (!empty($q)) {
       $argString = trim($q);
+      // remove / from the beginning and ending of query string.
+      $argString = trim($argString, '/');
       $args = explode('/', $argString);
     }
     $args = array_pad($args, 2, '');
